@@ -9,6 +9,10 @@ from git import Repo
 LOGGER = logging.getLogger(__name__)
 
 
+def get_zip_addon_path(thirdparty_path: Path) -> Path:
+    return thirdparty_path / "custom"
+
+
 def get_odoo_module_paths(search_folders: Union[List[Path], Path]) -> List[Path]:
     """List all Valid odoo module names in one or many Odoo addons folder.
 
@@ -101,7 +105,6 @@ def get_depends_of_module(
         return []
     already_done_modules.append(module_to_check.absolute())
 
-    LOGGER.debug("Loading Manifest: %s", manifest_path.absolute())
     manifest = literal_eval(manifest_path.read_text())
     module_depends = manifest.get("depends", [])
     sub_depends = []
@@ -122,7 +125,6 @@ def get_depends_of_module(
 def get_addon_paths(
     odoo_main_repo: Path,
     workspace_addon_path: Path,
-    zip_addon_path: Path,
     thirdparty_addon_path: Path,
 ) -> List[Path]:
     """Get Odoo Addon Paths for odoo.conf.
@@ -133,8 +135,6 @@ def get_addon_paths(
         Path to main odoo repo
     workspace_addon_path : Path
         Path to workspace addons
-    zip_addon_path : Path
-        path to zip addons
     thirdparty_addon_path : Path
         path to git cloned addon repos
 
@@ -146,6 +146,7 @@ def get_addon_paths(
     odoo_addon_paths = [odoo_main_repo / "addons"]
     if get_odoo_module_paths(workspace_addon_path):
         odoo_addon_paths.append(workspace_addon_path)
+    zip_addon_path = get_zip_addon_path(thirdparty_addon_path)
     zip_addon_repos = [f for f in zip_addon_path.iterdir() if f.is_dir() and get_odoo_module_paths(f)]
     odoo_addon_paths += zip_addon_repos
     git_thirdparty_addon_repos = [
@@ -155,6 +156,27 @@ def get_addon_paths(
     return odoo_addon_paths
 
 
+def _get_odoo_main_path(addon_paths: List[Path]) -> Path:
+    """Get Odoo main path by location of odoo-bin from addon folders.
+
+    Parameters
+    ----------
+    addon_paths : List[Path]
+        List of possible paths
+
+    Returns
+    -------
+    Path
+        Path with odoo-bin and main addons folder
+    """
+    for path in addon_paths:
+        # The main odoo addon path is odoo/addons.
+        # so one up should be the launch script
+        bin_path = path.parent / "odoo-bin"
+        if bin_path.exists() and bin_path.is_file():
+            return path
+
+
 def _get_python_requirements_of_modules(addon_paths: List[Path], filter_module_names: List[str] = None):
     """Install python requirements mentioned in module manifests
 
@@ -170,31 +192,42 @@ def _get_python_requirements_of_modules(addon_paths: List[Path], filter_module_n
 
     if not filter_module_names:
         filter_module_names = available_module_names
-    filter_module_names = [f for f in filter_module_names if f not in ["base", "web"]]
-    LOGGER.info("Checking python requirements of Modules: %s", ", ".join(sorted(filter_module_names)))
+    filter_module_names = [f for f in filter_module_names if f != "base"]
 
-    if unavailable_modules := [m for m in filter_module_names if m not in available_module_names]:
-        LOGGER.warning("Couldn't search Python reqs for unavailable Modules: %s", ", ".join(unavailable_modules))
+    LOGGER.info("Checking python requirements of Modules:\n%s", "\n".join(sorted(filter_module_names)))
+    if unavailable_modules := set(filter_module_names).difference(available_module_names):
+        LOGGER.warning("Could not find __manifest__ for:\n%s", "\n".join(unavailable_modules))
+        LOGGER.debug("Search Paths:\n%s", "\n".join(map(str, addon_paths)))
 
     check_modules = [mp for mp in available_modules if mp.stem in filter_module_names]
+
+    if odoo_main_path := _get_odoo_main_path(addon_paths):
+        # When the Odoo main path is in the supplied path, exclude those modules.
+        # Odoos base requirements are set in their requirements.txt
+        LOGGER.debug("Py install: Excluding Odoo main Modules in: '%s'", odoo_main_path)
+        check_modules = [mp for mp in check_modules if odoo_main_path not in mp.parents]
+
     check_modules_dependencies = []
     for module in check_modules:
         check_modules_dependencies += get_depends_of_module(
             available_modules, module, already_done_modules=check_modules_dependencies
         )
     LOGGER.debug(
-        "adding child modules to check list: %s", ", ".join(sorted([p.stem for p in check_modules_dependencies]))
+        "adding children of requested modules to check list:\n%s",
+        "\n".join(sorted([p.stem for p in check_modules_dependencies])),
     )
 
     check_modules += check_modules_dependencies
 
+    check_modules = set(check_modules)
+
     if not check_modules:
         LOGGER.debug("No Modules provided to check for python Requirements")
         return
     python_depends = []
     for module_path in check_modules:
+        LOGGER.debug("Checking for External Depends: %s", module_path)
         manifest_path = module_path / "__manifest__.py"
-        LOGGER.debug("Loading Manifest: %s", manifest_path.absolute())
         manifest = literal_eval(manifest_path.read_text())
         if module_depends := manifest.get("external_dependencies", {}).get("python"):
             python_depends += module_depends
